@@ -48,7 +48,7 @@ def _datedir_repo_from_defn(publisher_defn):
     if error_dir is None:
         raise AssertionError(
                 "Missing error_dir key: %s" % str(publisher_defn))
-    for arg in ('instance_id', 'inherit_id', 'stash_path'):
+    for arg in ('inherit_id', 'stash_path'):
         if arg in publisher_defn:
             kwargs[arg] = publisher_defn[arg]
     return DateDirRepo(error_dir, **kwargs).publish
