@@ -69,15 +69,6 @@ class ConfigFromDictTests(TestCase):
         config = self.get_config_from_dict([publisher_defn])
         self.assertEqual(error_dir, config.publishers[0].im_self.root)
 
-    def test_datedir_sets_instance_id_on_repo(self):
-        instance_id = self.getUniqueString()
-        publisher_defn = dict(type='datedir', error_dir=self.getUniqueString(),
-                instance_id=instance_id)
-        config = self.get_config_from_dict([publisher_defn])
-        # The instance id isn't set as an attribute, but is passed to
-        # another object, so we check that instead.
-        self.assertEqual(instance_id, config.publishers[0].im_self.log_namer.get_log_infix())
-
     def test_datedir_sets_inherit_id_on_repo(self):
         inherit_id = True
         publisher_defn = dict(type='datedir', error_dir=self.getUniqueString(),
